MethodChannelWeLocationFlutter class
Method channel implementation for webengage_flutter_location.
This plugin is dependency-only and does not use method channels.
- Inheritance
-
- Object
- PlatformInterface
- WeLocationFlutterPlatform
- MethodChannelWeLocationFlutter
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited